#!/bin/bash

# Log file location
LOG_FILE="/tmp/app_permissions_check.log"

# Function to append output to the log file
log() {
    echo "[$(date)] $1" >> "$LOG_FILE"
}

# Start logging
log "=== App Permissions Check Started ==="

# 1. Effective User and Group IDs
log "Effective User and Group IDs:"
id >> "$LOG_FILE" 2>&1

# 2. Environment Variables
log "Environment Variables:"
printenv >> "$LOG_FILE" 2>&1

# 3. Current Directory Permissions
log "Current Directory Permissions:"
ls -ld "$(pwd)" >> "$LOG_FILE" 2>&1

# 4. File Read/Write Test
TEST_FILE="/tmp/app_permissions_test.txt"

# Attempt to write to a test file
log "Testing File Write Permission:"
echo "Testing write permissions at $(date)" > "$TEST_FILE" 2>> "$LOG_FILE"

if [ $? -eq 0 ]; then
    log "File write test successful: $TEST_FILE"
else
    log "File write test failed!"
fi

# Attempt to read the test file
log "Testing File Read Permission:"
cat "$TEST_FILE" >> "$LOG_FILE" 2>&1

if [ $? -eq 0 ]; then
    log "File read test successful."
else
    log "File read test failed!"
fi

# Clean up the test file
rm -f "$TEST_FILE"

# 5. System Integrity Protection (SIP) Status
log "Checking System Integrity Protection (SIP) Status:"
csrutil status >> "$LOG_FILE" 2>&1

# Finish logging
log "=== App Permissions Check Completed ==="

# Output the log file path
echo "Permissions check completed. See the log at: $LOG_FILE"
